@@ -109,7 +109,7 @@ module_flat (RECODE_OUTER outer)
   return true;
 }
 
-_GL_ATTRIBUTE_CONST void
+void
 delmodule_flat (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
