@@ -198,7 +198,7 @@ module_latin1_ascii (RECODE_OUTER outer)
   return true;
 }
 
-_GL_ATTRIBUTE_CONST void
+void
 delmodule_latin1_ascii (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
