@@ -413,7 +413,7 @@ module_varia (RECODE_OUTER outer)
   ;
 }
 
-_GL_ATTRIBUTE_CONST void
+void
 delmodule_varia (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
