@@ -455,7 +455,7 @@ module_vietnamese (RECODE_OUTER outer)
   return true;
 }
 
-_GL_ATTRIBUTE_CONST void
+void
 delmodule_vietnamese (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
